@@ -1,5 +1,6 @@
 import mysql.connector
 import requests
+import hashlib
 from . import api
 
 def get_credentials(api_key, schema='prod'):
@@ -23,4 +24,10 @@ def get(api_key, schema, buffered=True, dictionary=False):
     )
     
     cur = cnx.cursor(buffered=buffered, dictionary=dictionary)
-    return cnx, cur
\ No newline at end of file
+    return cnx, cur
+
+def hash(url):
+    return hashlib.sha256(url.encode()).hexdigest()
+
+if __name__ == '__main__':
+    pass
\ No newline at end of file
